<?php
    // get the data from the form
    $investment = filter_input(INPUT_POST, 'investment', FILTER_VALIDATE_FLOAT);
    $interest_rate = filter_input(INPUT_POST, 'interest_rate', FILTER_VALIDATE_FLOAT);
    $years = filter_input(INPUT_POST, 'years', FILTER_VALIDATE_INT);
    $firstname = filter_input(INPUT_POST, 'first_name');
    $lastname = filter_input(INPUT_POST, 'last_name');
    $email = filter_input(INPUT_POST, 'email', FILTER_VALIDATE_EMAIL);
    $products = filter_input(INPUT_POST, 'products', FILTER_SANITIZE_SPECIAL_CHARS, FILTER_REQUIRE_ARRAY);    

    // print_r is handy way to echo out an array
    //
    //print_r($products);
    //
    
    // validate investment
    if ($investment === FALSE ) {
        $error_message = 'Investment must be a valid number.'; 
    } else if ( $investment <= 0 ) {
        $error_message = 'Investment must be greater than zero.'; 
    // validate interest rate
    } else if ( $interest_rate === FALSE )  {
        $error_message = 'Interest rate must be a valid number.'; 
    } else if ( $interest_rate <= 0 ) {
        $error_message = 'Interest rate must be greater than zero.'; 
    // validate years
    } else if ( $years === FALSE ) {
        $error_message = 'Years must be a valid whole number.';
    } else if ( $years <= 0 ) {
        $error_message = 'Years must be greater than zero.';
    } else if ( $years > 30 ) {
        $error_message = 'Years must be less than 31.';
    // set error message to empty string if no invalid entries
    } else {
        $error_message = ''; 
    }

    // if an error message exists, go to the index page
    if ($error_message != '') {
        include('index.php');
        exit();
    }

    // calculate the future value
    $future_value = $investment;
    for ($i = 1; $i <= $years; $i++) {
        $future_value = ($future_value + ($future_value * $interest_rate *.01));
    }

    // apply currency and percent formatting
    $investment_f = '$'.number_format($investment, 2);
    $yearly_rate_f = $interest_rate.'%';
    $future_value_f = '$'.number_format($future_value, 2);
?>
<!DOCTYPE html>
<html>
<head>
    <title>Future Value Calculator</title>
    <link rel="stylesheet" type="text/css" href="main.css"/>
</head>
<body>
    <main>
        <h1>Future Value Calculator</h1>
        <h2>Your contact information</h2>
        <label>First name:</label>
        <span><?php echo htmlspecialchars($firstname); ?></span><br>
        <label>Last name:</label>
        <span><?php echo htmlspecialchars($lastname); ?></span><br>
        <label>Email:</label>
        <span><?php echo htmlspecialchars($email); ?></span><br>
        <label>Products:</label><br>
        <ul>
        <?php
        /* ONE WAY TO DO IT
        foreach ($products as $product_index => $product_value ) {
            echo '<li>';
            echo $product_value;
            echo '</li>';
        } // end foreach
        */
        /* ANOTHER WAY TO DO IT */
        for ($i = 0; $i < count($products); $i++ ) {
            echo '<li>';
            echo $products[$i];
            echo '</li>';
        } // end foreach
        ?>
        </ul>
        <br>
        
        <h2>Your forecast</h2>
        <label>Investment Amount:</label>
        <span><?php echo $investment_f; ?></span><br>

        <label>Yearly Interest Rate:</label>
        <span><?php echo $yearly_rate_f; ?></span><br>

        <label>Number of Years:</label>
        <span><?php echo $years; ?></span><br>

        <label>Future Value:</label>
        <span><?php echo $future_value_f; ?></span><br>
    </main>
</body>
</html>